#ifndef timeObj_h
#define timeObj_h

// Insainly handy for doing things in the background.
// Set the timer and wait 'till it goes "ding". 
// Great for blinking LEDs, updating readings, etc.
// May not fast & accurate enough for RC Servos.
// *** Takes care of roll over issues ***
//
// NOTE: Once the timer expires, every call to ding() will return true until its been
// restarted.


class timeObj {

	public:
  				timeObj(float inMs=10,bool startNow=true);
	virtual	~timeObj(void);
	
  				void 				setTime(float inMs,bool startNow=true);	// Change the time duration for next start..
  	virtual	void 				start(void);                       			// Start the timer "now".
  	virtual	void 				stepTime(void);                    			// Restart the timer from last end time.
  				bool				ding(void);											// Timer has expired.
  				unsigned long	getTime(void);										// How long does this go for?
  				float				getFraction(void);								// Fuel gauge. What fraction of time is left.
  				void				printState(void);									// Debugging.
  				
	private:
				enum	timeObjStates	{ preStart, running, expired };
				
				timeObjStates	ourState;
  				unsigned long	waitTime;
  				unsigned long	startTime;
  				unsigned long	endTime;
};

#endif

